package de.intevation.gnv.propertiesreader;

import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.ServletConfig;

import org.apache.log4j.Logger;

/**
 * This reader fetches the properties it will provide from the 
 * <code>ServletConfig</code> of an <code>Context</code>.
 * It will read the InitParameters which could be configured using
 * the <code>web.xml</code-file of each <code>context</code>.
 * 
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class ServletPropertiesReader implements PropertiesReader {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(ServletPropertiesReader.class);

    /**
     * The properties which are read from the <code>ServletConfig</code>.
     */
    private Map<String, String> properties = null;

    /**
     * Constructor
     * 
     * @param config the <code>ServletConfig</code> where 
     *               the properties should be read from.
     */
    public ServletPropertiesReader(ServletConfig config) {
        super();
        log.info("ServletPropertiesReader will be initialized");
        if (config != null) {

            Enumeration<String> keys = config.getInitParameterNames();
            properties = new HashMap<String, String>();
            while (keys.hasMoreElements()) {
                String key = keys.nextElement();
                String value = config.getInitParameter(key);
                log.info("New ConbfigurationValue; " + key + " ==> " + value);
                this.properties.put(key, value);
            }
        }
    }


    public String getPropertieValue(String key, String defaultValue) {
        String value = this.properties.get(key);
        if (value == null) {
            value = defaultValue;
        }
        return value;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
